/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2015 Frederik Heber. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * KeyValuePairsQtQuery.cpp
 *
 *  Created on: May 16, 2015
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <Qt/qpushbutton.h>
#include <Qt/qboxlayout.h>
#include <Qt/qlistwidget.h>

//#include "CodePatterns/MemDebug.hpp"

#include "UIElements/Qt4/Query/QtQuery.hpp"
#include "UIElements/Qt4/Query/QtQueryList.hpp"

#include "Parameters/Specifics/KeyValuePair.hpp"

QtDialog::KeyValuePairsQtQuery::KeyValuePairsQtQuery(Parameter<std::vector<KeyValuePair> > &_param, const std::string &_title, const std::string &_description,QBoxLayout *_parent,Dialog *_dialog) :
    QtQuery<std::vector<KeyValuePair> >(_param, _title, _description),
    QtQueryList<KeyValuePair>(_param, _parent, _dialog, temp)
{
  ListQuerySubDialog *subDialog = new ListQuerySubDialog(this, _title);
  subQuery = new KeyValuePairQtQuery(*subParam, _title, _description, thisVLayout, subDialog);
  subDialog->setSubQuery(subQuery);

  connect(inputList,SIGNAL(itemSelectionChanged()),this,SLOT(onElementSelected()));
  connect(addButton,SIGNAL(clicked()),this,SLOT(onAddElement()));
  connect(removeButton,SIGNAL(clicked()),this,SLOT(onRemoveElement()));
}

QtDialog::KeyValuePairsQtQuery::~KeyValuePairsQtQuery()
{
  delete(subQuery);
}

void QtDialog::KeyValuePairsQtQuery::onSubUpdate()
{
  addButton->setEnabled(subParam->isSet());
}

void QtDialog::KeyValuePairsQtQuery::onElementSelected() {
  elementSelected();
}

void QtDialog::KeyValuePairsQtQuery::onAddElement() {
  addElement();
  QtQuery<std::vector<KeyValuePair> >::handle();
}

void QtDialog::KeyValuePairsQtQuery::onRemoveElement() {
  removeElements();
  QtQuery<std::vector<KeyValuePair> >::handle();
}

